Manages database migrations for PgFlow's extension SQL functions.
These functions wrap custom queries (worker registration, stalled task recovery, etc.)
as PostgreSQL functions in the pgflow schema, called via RPC from PgFlow.Queries.* modules.
Usage in Ecto Migrations
defmodule MyApp.Repo.Migrations.AddPgflowExtensions do
use Ecto.Migration
def up, do: PgFlow.HelpersMigration.up()
def down, do: PgFlow.HelpersMigration.down()
end
Summary
Functions
Returns the current migration version supported by this library.
Rolls back migrations to the target version.
Returns the currently migrated version from the database.
Applies migrations up to the target version.
Functions
@spec current_version() :: pos_integer()
Returns the current migration version supported by this library.
@spec down(keyword()) :: :ok
Rolls back migrations to the target version.
Options
:prefix- Schema prefix. Defaults to"pgflow".:version- Target version to roll back to. Defaults to0.
@spec migrated_version(keyword()) :: non_neg_integer()
Returns the currently migrated version from the database.
Returns 0 if no migrations have been applied.
@spec up(keyword()) :: :ok
Applies migrations up to the target version.
Options
:prefix- Schema prefix. Defaults to"pgflow".:version- Target version. Defaults to1.