Type badge component for distinguishing between flows, jobs, and crons.
Summary
Functions
Renders a type badge for flows, jobs, and crons.
Functions
Renders a type badge for flows, jobs, and crons.
Flows get a small purple "flow" pill badge. Jobs get a small blue "job" pill badge. Crons get a small amber "cron" pill badge.
Attributes
:type- The flow type ("flow", "job", or "cron").
Examples
<TypeBadge.type_badge type="flow" />
<TypeBadge.type_badge type="job" />
<TypeBadge.type_badge type="cron" />
<TypeBadge.type_badge type={@flow_type} />Attributes
type(:string) - Defaults to"flow".